package com.zjsgfa.project.zjsgfa.mapper;

import java.util.List;

import com.zjsgfa.project.zjsgfa.domain.SjLjfzqk;
import com.zjsgfa.project.zjsgfa.domain.SjLjzjyfzqk;

/**
 * 邻井复杂情况-钻井液Mapper接口
 * 
 * @author ruoyi
 * @date 2026-02-24
 */
public interface SjLjzjyfzqkMapper 
{
    /**
     * 查询邻井复杂情况-钻井液
     * 
     * @param id 邻井复杂情况-钻井液主键
     * @return 邻井复杂情况-钻井液
     */
    public SjLjzjyfzqk selectSjLjzjyfzqkById(Long id);

    /**
     * 查询邻井复杂情况-钻井液列表
     * 
     * @param sjLjzjyfzqk 邻井复杂情况-钻井液
     * @return 邻井复杂情况-钻井液集合
     */
    public List<SjLjzjyfzqk> selectSjLjzjyfzqkList(SjLjzjyfzqk sjLjzjyfzqk);

    /**
     * 新增邻井复杂情况-钻井液
     * 
     * @param sjLjzjyfzqk 邻井复杂情况-钻井液
     * @return 结果
     */
    public int insertSjLjzjyfzqk(SjLjzjyfzqk sjLjzjyfzqk);

    /**
     * 修改邻井复杂情况-钻井液
     * 
     * @param sjLjzjyfzqk 邻井复杂情况-钻井液
     * @return 结果
     */
    public int updateSjLjzjyfzqk(SjLjzjyfzqk sjLjzjyfzqk);

    /**
     * 删除邻井复杂情况-钻井液
     * 
     * @param id 邻井复杂情况-钻井液主键
     * @return 结果
     */
    public int deleteSjLjzjyfzqkById(Long id);

    /**
     * 批量删除邻井复杂情况-钻井液
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteSjLjzjyfzqkByIds(Long[] ids);

    int deleteSjLjzjyfzqkByZbid(Long zbid);

    int insertSjLjzjyfzqkBatch(List<SjLjfzqk> jsqaList);

}
