package com.zjsgfa.project.zjsgfa.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.zjsgfa.project.zjsgfa.domain.SjLjjw;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.zjsgfa.framework.aspectj.lang.annotation.Log;
import com.zjsgfa.framework.aspectj.lang.enums.BusinessType;
import com.zjsgfa.project.zjsgfa.domain.SjLjzjyfzqk;
import com.zjsgfa.project.zjsgfa.service.ISjLjzjyfzqkService;
import com.zjsgfa.framework.web.controller.BaseController;
import com.zjsgfa.framework.web.domain.AjaxResult;
import com.zjsgfa.common.utils.poi.ExcelUtil;
import com.zjsgfa.framework.web.page.TableDataInfo;

/**
 * 邻井复杂情况-钻井液Controller
 * 
 * @author ruoyi
 * @date 2026-02-24
 */
@RestController
@RequestMapping("/system/sjLjzjyfzqk")
public class SjLjzjyfzqkController extends BaseController
{
    @Autowired
    private ISjLjzjyfzqkService sjLjzjyfzqkService;

    /**
     * 查询邻井复杂情况-钻井液列表
     */
    //@PreAuthorize("@ss.hasPermi('system:sjLjzjyfzqk:list')")
    @GetMapping("/list")
    public TableDataInfo list(SjLjzjyfzqk sjLjzjyfzqk)
    {
//        startPage();
        List<SjLjzjyfzqk> list = sjLjzjyfzqkService.selectSjLjzjyfzqkList(sjLjzjyfzqk);
        return getDataTable(list);
    }

    /**
     * 导出邻井复杂情况-钻井液列表
     */
    //@PreAuthorize("@ss.hasPermi('system:sjLjzjyfzqk:export')")
    @Log(title = "邻井复杂情况-钻井液", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, SjLjzjyfzqk sjLjzjyfzqk)
    {
        List<SjLjzjyfzqk> list = sjLjzjyfzqkService.selectSjLjzjyfzqkList(sjLjzjyfzqk);
        ExcelUtil<SjLjzjyfzqk> util = new ExcelUtil<SjLjzjyfzqk>(SjLjzjyfzqk.class);
        util.exportExcel(response, list, "邻井复杂情况-钻井液数据");
    }

    /**
     * 获取邻井复杂情况-钻井液详细信息
     */
    //@PreAuthorize("@ss.hasPermi('system:sjLjzjyfzqk:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(sjLjzjyfzqkService.selectSjLjzjyfzqkById(id));
    }

    /**
     * 新增邻井复杂情况-钻井液
     */
    //@PreAuthorize("@ss.hasPermi('system:sjLjzjyfzqk:add')")
    @Log(title = "邻井复杂情况-钻井液", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody SjLjzjyfzqk sjLjzjyfzqk)
    {
        return toAjax(sjLjzjyfzqkService.insertSjLjzjyfzqk(sjLjzjyfzqk));
    }

    /**
     * 修改邻井复杂情况-钻井液
     */
    //@PreAuthorize("@ss.hasPermi('system:sjLjzjyfzqk:edit')")
    @Log(title = "邻井复杂情况-钻井液", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody SjLjzjyfzqk sjLjzjyfzqk)
    {
        return toAjax(sjLjzjyfzqkService.updateSjLjzjyfzqk(sjLjzjyfzqk));
    }

    /**
     * 删除邻井复杂情况-钻井液
     */
    //@PreAuthorize("@ss.hasPermi('system:sjLjzjyfzqk:remove')")
    @Log(title = "邻井复杂情况-钻井液", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(sjLjzjyfzqkService.deleteSjLjzjyfzqkByIds(ids));
    }


    @PostMapping("/pladd2")
    public AjaxResult pladd2(@RequestBody List<SjLjjw> list) throws Exception
    {
        return toAjax(sjLjzjyfzqkService.insertSjLjzjyfzqkBatch(list));
    }
}
